@@ -303,7 +303,7 @@ leaflet_stars = function(x,
   m = leaflet::addScaleBar(map = m, position = "bottomleft")
   m = leafem::addMouseCoordinates(m)
   m = leafem::addCopyExtent(m)
-  if (homebutton) m = leafem::addHomeButton(m, ext, group = layer.name)
+  if (homebutton) m = leafem::addHomeButton(m, ext, group = gsub("[[:punct:] ]", "_", layer.name))
 
   if (hide) {
     m = leaflet::hideGroup(m, layer.name)
